<?php
namespace Folha\Repositories;

class GpeOcupacaoh extends \Doctrine\ORM\EntityRepository
{

    /**
     * Retorna os dados para a geracao do arquivo de integracao com o e-Social, para o evento de "tabela de cargos".
     * OBS.: Este método foi utilizado somente como exemplo do que pode ser feito, para a geração dos arquivos do 
     *       e-Social. Para sua aplicação em produção, este deve ser revisto, para que os devidos dados sejam 
     *       retornados.
     * 
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author paulopereira
     **/
    function dataSetEsocial_S1030($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, $utilizaIntervaloDeDatas, $nrorg, $versaoHRM)
    {
        // $sql = "SELECT '__ID__' ID, 'S-1030' VERSAO, 1 TPAMB, 1 PROCEMI, 1 INDSEGMENTO, '$versaoHRM' VERPROC, 
        //             '__TPINSCRICAO__' TPINSCRICAO, '__NRINSCRICAO__' NRINSCRICAO,
        //             OM.NROCUPACAOM CODCARGO, OH.NMOCUPACAOH DESCCARGO, TO_CHAR(OM.DTINIVIGENCIA, 'MMYYYY') INIVALIDADE, TO_CHAR(OM.DTFIMVIGENCIA, 'MMYYYY') FIMVALIDADE,
        //             CASE WHEN (
        //               SELECT COUNT(1) ITENS_HISTORICO
        //                 FROM GPE_OCUPACAOH
        //                 WHERE GPE_OCUPACAOH.NROCUPACAOM = OH.NROCUPACAOM
        //                   AND GPE_OCUPACAOH.NRORG = OH.NRORG 
        //             ) > 1 THEN 0 ELSE 1 END AS INCLUSAO,
        //             CASE WHEN (
        //               SELECT COUNT(1) ITENS_HISTORICO
        //                 FROM GPE_OCUPACAOH
        //                 WHERE GPE_OCUPACAOH.NROCUPACAOM = OH.NROCUPACAOM
        //                   AND GPE_OCUPACAOH.NRORG = OH.NRORG 
        //             ) > 1 THEN 1 ELSE 0 END AS ALTERACAO
        //           FROM GPE_OCUPACAOM OM
        //           INNER JOIN GPE_OCUPACAOH OH
        //             ON OM.NROCUPACAOM = OH.NROCUPACAOM
        //             AND OM.NRORG      = OH.NRORG
        //           WHERE OM.NRORG      = $nrorg
        //           AND OH.DTMESCOMPETENC = (
        //             SELECT MAX(DTMESCOMPETENC)
        //               FROM GPE_OCUPACAOH
        //               WHERE GPE_OCUPACAOH.NROCUPACAOM = OH.NROCUPACAOM
        //                 AND GPE_OCUPACAOH.NRORG = OH.NRORG
        //                 AND WHERE_PLACEHOLDER
        //           )
        //           ORDER BY OM.NROCUPACAOM";

        $sql = "SELECT '__ID__' id,
                  'S-1030' versao,
                  '1' tpAmb,
                  '1' procEmi,
                  '1' indSegmento,
                  '$versaoHRM' verProc,
                  '__tpInscicaoEmpregador__' tpInscricao,
                  '__nrInscricaoEmpregador__' nrInscricao,
                  Om.Nrocupacaom codFuncao,
                  to_char(Om.Dtinivigencia, 'MMYYYY') iniValidade,
                  Oh.Nmocupacaoh descFuncao,
                  1 inclusao,
                  0 alteracao,
                  1 novavalidade,
                  0 exclusao
                from Gpe_Ocupacaom om
                inner join Gpe_Ocupacaoh oh
                  on Oh.Dtmescompetenc = (
                    SELECT MAX(Dtmescompetenc)
                      from Gpe_Ocupacaoh
                      where Gpe_Ocupacaoh.Nrocupacaom = oh.Nrocupacaom 
                        and Gpe_Ocupacaoh.nrorg       = oh.nrorg
                  )
                  and Oh.Nrocupacaom = Om.Nrocupacaom
                  and Oh.nrorg       = Om.nrorg
                where Oh.nrorg = $nrorg
                  and WHERE_PLACEHOLDER";
        $where = "1=1";
        $sql = str_replace("WHERE_PLACEHOLDER", $where, $sql);

        // Esta linha está sendo utilizada somente para limitar o resultset utilizado para a aplicacao. Este deve ser
        // removido para a utilizacao dos sistema em produção.
        $sql = "SELECT teste.*, rownum from ($sql) teste where rownum < 10";
                  
        return \Setforms2\Shared\Connection::getInstance()->fetchAll($sql);
    }

    /**
     * Retorna os dados para a geracao do arquivo de integracao com o e-Social, para o evento de "tabela de cargos".
     * OBS.: Este método foi utilizado somente como exemplo do que pode ser feito, para a geração dos arquivos do 
     *       e-Social. Para sua aplicação em produção, este deve ser revisto, para que os devidos dados sejam 
     *       retornados.
     * 
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author paulopereira
     **/
    function dataSetEsocial_S1040($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, $utilizaIntervaloDeDatas, $nrorg, $versaoHRM)
    {
        // $sql = "SELECT '__ID__' ID, 'S-1030' VERSAO, 1 TPAMB, 1 PROCEMI, 1 INDSEGMENTO, '$versaoHRM' VERPROC, 
        //             '__TPINSCRICAO__' TPINSCRICAO, '__NRINSCRICAO__' NRINSCRICAO,
        //             OM.NROCUPACAOM CODCARGO, OH.NMOCUPACAOH DESCCARGO, TO_CHAR(OM.DTINIVIGENCIA, 'MMYYYY') INIVALIDADE, TO_CHAR(OM.DTFIMVIGENCIA, 'MMYYYY') FIMVALIDADE,
        //             CASE WHEN (
        //               SELECT COUNT(1) ITENS_HISTORICO
        //                 FROM GPE_OCUPACAOH
        //                 WHERE GPE_OCUPACAOH.NROCUPACAOM = OH.NROCUPACAOM
        //                   AND GPE_OCUPACAOH.NRORG = OH.NRORG 
        //             ) > 1 THEN 0 ELSE 1 END AS INCLUSAO,
        //             CASE WHEN (
        //               SELECT COUNT(1) ITENS_HISTORICO
        //                 FROM GPE_OCUPACAOH
        //                 WHERE GPE_OCUPACAOH.NROCUPACAOM = OH.NROCUPACAOM
        //                   AND GPE_OCUPACAOH.NRORG = OH.NRORG 
        //             ) > 1 THEN 1 ELSE 0 END AS ALTERACAO
        //           FROM GPE_OCUPACAOM OM
        //           INNER JOIN GPE_OCUPACAOH OH
        //             ON OM.NROCUPACAOM = OH.NROCUPACAOM
        //             AND OM.NRORG      = OH.NRORG
        //           WHERE OM.NRORG      = $nrorg
        //           AND OH.DTMESCOMPETENC = (
        //             SELECT MAX(DTMESCOMPETENC)
        //               FROM GPE_OCUPACAOH
        //               WHERE GPE_OCUPACAOH.NROCUPACAOM = OH.NROCUPACAOM
        //                 AND GPE_OCUPACAOH.NRORG = OH.NRORG
        //                 AND WHERE_PLACEHOLDER
        //           )
        //           ORDER BY OM.NROCUPACAOM";

        $sql = "SELECT '__ID__' id,
                  'S-1040' versao,
                  '1' tpAmb,
                  '1' procEmi,
                  '1' indSegmento,
                  '$versaoHRM' verProc,
                  '__tpInscicaoEmpregador__' tpInscricao,
                  '__nrInscricaoEmpregador__' nrInscricao,
                  Om.Nrocupacaom codFuncao,
                  to_char(Om.Dtinivigencia, 'MMYYYY') iniValidade,
                  Oh.Nmocupacaoh descFuncao,
                  1 inclusao,
                  0 alteracao,
                  1 novavalidade,
                  0 exclusao
                from Gpe_Ocupacaom om
                inner join Gpe_Ocupacaoh oh
                  on Oh.Dtmescompetenc = (
                    SELECT MAX(Dtmescompetenc)
                      from Gpe_Ocupacaoh
                      where Gpe_Ocupacaoh.Nrocupacaom = oh.Nrocupacaom 
                        and Gpe_Ocupacaoh.nrorg       = oh.nrorg
                  )
                  and Oh.Nrocupacaom = Om.Nrocupacaom
                  and Oh.nrorg       = Om.nrorg
                where Oh.nrorg = $nrorg
                  and WHERE_PLACEHOLDER";
        $where = "1=1";
        $sql = str_replace("WHERE_PLACEHOLDER", $where, $sql);

        // Esta linha está sendo utilizada somente para limitar o resultset utilizado para a aplicacao. Este deve ser
        // removido para a utilizacao dos sistema em produção.
        $sql = "SELECT teste.*, rownum from ($sql) teste where rownum < 10";
                  
        return \Setforms2\Shared\Connection::getInstance()->fetchAll($sql);
    }

}